"""
Author: Michel Peltriaux
Organization: Struktur- und Genehmigungsdirektion Nord, Rhineland-Palatinate, Germany
Contact: michel.peltriaux@sgdnord.rlp.de
Created on: 30.11.20

"""
from django.urls import path

from compensation.views import compensation_views
from compensation.views import payment_views
from compensation.views import eco_account_views

app_name = "compensation"

# Split lists for each sub-component for better overview
urlpatterns_payment = [
    path('pay/<intervention_id>/new', payment_views.new_payment_view, name='pay-new'),
    path('pay/<id>/remove', payment_views.payment_remove_view, name='pay-remove'),
]

urlaptterns_eco_acc = [
    path("acc/", eco_account_views.index_view, name="acc-index"),
    path('acc/new/', eco_account_views.new_view, name='acc-new'),
    path('acc/<id>', eco_account_views.open_view, name='acc-open'),
    path('acc/<id>/log', eco_account_views.log_view, name='acc-log'),
    path('acc/<id>/record', eco_account_views.record_view, name='acc-record'),
    path('acc/<id>/edit', eco_account_views.edit_view, name='acc-edit'),
    path('acc/<id>/remove', eco_account_views.remove_view, name='acc-remove'),
    path('acc/<id>/state/new', eco_account_views.state_new_view, name='acc-new-state'),
    path('acc/<id>/action/new', eco_account_views.action_new_view, name='acc-new-action'),
    path('acc/<id>/deadline/new', eco_account_views.deadline_new_view, name="acc-new-deadline"),

    # Documents
    # Document remove route can be found in konova/urls.py
    path('acc/<id>/document/new/', eco_account_views.new_document_view, name='acc-new-doc'),

    # Eco-account withdraws
    path('acc/<id>/remove/<withdraw_id>', eco_account_views.withdraw_remove_view, name='withdraw-remove'),
    path('acc/<id>/withdraw/new', eco_account_views.new_withdraw_view, name='acc-new-withdraw'),

]
urlpatterns_compensation = [
    # Main compensation
    path("", compensation_views.index_view, name="index"),
    path('new', compensation_views.new_view, name='new'),
    path('<id>', compensation_views.open_view, name='open'),
    path('<id>/log', compensation_views.log_view, name='log'),
    path('<id>/edit', compensation_views.edit_view, name='edit'),
    path('<id>/remove', compensation_views.remove_view, name='remove'),
    path('<id>/state/new', compensation_views.state_new_view, name='new-state'),
    path('<id>/action/new', compensation_views.action_new_view, name='new-action'),
    path('<id>/deadline/new', compensation_views.deadline_new_view, name="new-deadline"),

    # Documents
    # Document remove route can be found in konova/urls.py
    path('<id>/document/new/', compensation_views.new_document_view, name='new-doc'),

    # Generic state routes
    path('state/<id>/remove', compensation_views.state_remove_view, name='state-remove'),

    # Generic action routes
    path('action/<id>/remove', compensation_views.action_remove_view, name='action-remove'),

]

# Merge all together in the end
urlpatterns = urlpatterns_compensation + urlaptterns_eco_acc + urlpatterns_payment
