"""
Author: Michel Peltriaux
Organization: Struktur- und Genehmigungsdirektion Nord, Rhineland-Palatinate, Germany
Contact: michel.peltriaux@sgdnord.rlp.de
Created on: 07.12.20

"""
from dal_select2.views import Select2QuerySetView

from compensation.models import EcoAccount
from intervention.models import Intervention
from organisation.models import Organisation


class OrganisationAutocomplete(Select2QuerySetView):
    def get_queryset(self):
        if self.request.user.is_anonymous:
            return Organisation.objects.none()
        qs = Organisation.objects.all()
        if self.q:
            qs = qs.filter(name__icontains=self.q)
            qs = qs.order_by(
                "name"
            )
        return qs


class NonOfficialOrganisationAutocomplete(Select2QuerySetView):
    def get_queryset(self):
        if self.request.user.is_anonymous:
            return Organisation.objects.none()
        qs = Organisation.objects.all()
        if self.q:
            qs = qs.filter(
                name__icontains=self.q,
            )
            qs = qs.order_by(
                "name"
            )
        return qs


class EcoAccountAutocomplete(Select2QuerySetView):
    def get_queryset(self):
        if self.request.user.is_anonymous:
            return EcoAccount.objects.none()
        qs = EcoAccount.objects.filter(
            deleted=None,
            recorded__isnull=False,
        )
        if self.q:
            qs = qs.filter(
                identifier__icontains=self.q
            )
            qs = qs.order_by(
                "identifier"
            )
        return qs


class InterventionAutocomplete(Select2QuerySetView):
    def get_queryset(self):
        if self.request.user.is_anonymous:
            return Intervention.objects.none()
        qs = Intervention.objects.filter(
            deleted=None,
            users__in=[self.request.user],
        )
        if self.q:
            qs = qs.filter(
                identifier__icontains=self.q
            )
            qs = qs.order_by(
                "identifier"
            )
        return qs